@@ -3,10 +3,11 @@ use std::collections::BTreeMap;
 use std::time::Duration;
 
 use async_channel::{Receiver, Sender};
+use async_compat::CompatExt;
 use gio::prelude::*;
-use glib::subclass::prelude::{ObjectSubclass, *};
 use glib::subclass::Signal;
-use glib::{clone, Properties, SourceId};
+use glib::subclass::prelude::{ObjectSubclass, *};
+use glib::{Properties, SourceId, clone};
 use once_cell::sync::Lazy;
 use transmission_client::{
     Authentication, Client, ClientError, Torrent, TorrentFiles, TorrentPeers,
@@ -116,7 +117,7 @@ mod imp {
                 self.obj().disconnect(false).await;
             }
 
-            debug!("Connect to {} ...", address);
+            debug!("Connect to {address} ...");
 
             // Check if the address has changed, and delete cached auth information if
             // needed
@@ -138,7 +139,7 @@ mod imp {
             self.obj().notify_address();
 
             // Check server version
-            let session = client.session().await?;
+            let session = client.session().compat().await?;
             debug!(
                 "Connected to transmission session version {}",
                 session.version
@@ -223,7 +224,7 @@ mod imp {
 
         pub async fn poll_data(&self, is_initial_poll: bool) -> Result<(), ClientError> {
             if let Some(client) = self.obj().rpc_client() {
-                let torrents = client.torrents(None).await?;
+                let torrents = client.torrents(None).compat().await?;
 
                 // Transmission assigns each torrent a "global" queue position, which means
                 // *every* torrent has a queue position, ignoring the torrent status. Therefore
@@ -261,12 +262,14 @@ mod imp {
                             (
                                 client
                                     .torrents_files(id.clone())
+                                    .compat()
                                     .await?
                                     .first()
                                     .cloned()
                                     .unwrap_or_default(),
                                 client
                                     .torrents_peers(id)
+                                    .compat()
                                     .await?
                                     .first()
                                     .cloned()
@@ -286,7 +289,7 @@ mod imp {
                             // ... yes -> emit torrent model `status-changed` signal
                             self.torrents.emit_by_name::<()>("status-changed", &[]);
                         } else {
-                            // Update torrent properties, without emiting the status-changed signal
+                            // Update torrent properties, without emitting the status-changed signal
                             torrent.refresh_values(&rpc_torrent, &torrent_files, &torrent_peers);
                         }
 
@@ -319,10 +322,10 @@ mod imp {
                     self.torrents.remove_torrent(&torrent);
                 }
 
-                let rpc_session = client.session().await?;
+                let rpc_session = client.session().compat().await?;
                 self.obj().session().refresh_values(rpc_session);
 
-                let rpc_session_stats = client.session_stats().await?;
+                let rpc_session_stats = client.session_stats().compat().await?;
                 self.obj()
                     .session_stats()
                     .refresh_values(rpc_session_stats, downloaded_torrents);
@@ -406,7 +409,7 @@ impl TrClient {
             rpc_client.set_authentication(Some(rpc_auth));
         }
 
-        let session = rpc_client.session().await?;
+        let session = rpc_client.session().compat().await?;
         debug!(
             "Connectivity test to {} succeeded: Transmission daemon version {}",
             address, session.version
@@ -417,7 +420,7 @@ impl TrClient {
 
     pub async fn test_port(&self) -> Result<bool, ClientError> {
         if let Some(rpc_client) = self.rpc_client() {
-            rpc_client.port_test().await
+            rpc_client.port_test().compat().await
         } else {
             warn!("Unable to test port, no rpc connection");
             Ok(false)
@@ -456,7 +459,7 @@ impl TrClient {
 
         if close_session {
             let client = imp.client.borrow().as_ref().unwrap().clone();
-            client.session_close().await.unwrap();
+            client.session_close().compat().await.unwrap();
         }
 
         let _client = imp.client.borrow_mut().take().unwrap();
@@ -468,7 +471,7 @@ impl TrClient {
 
         // Wait from message from polling loop to ensure we're not polling anymore.
         let r = imp.receiver.recv().await.unwrap();
-        debug!("Stopped polling: {:?}", r);
+        debug!("Stopped polling: {r:?}");
 
         // Not connected anymore -> clear torrents model
         self.torrents().clear();
@@ -485,7 +488,7 @@ impl TrClient {
     /// `filename` can be a magnet url or a local file path
     pub async fn add_torrent_by_filename(&self, filename: String) -> Result<(), ClientError> {
         if let Some(client) = self.rpc_client() {
-            client.torrent_add_filename(&filename).await?;
+            client.torrent_add_filename(&filename).compat().await?;
             self.refresh_data().await;
         } else {
             warn!("Unable to add new torrent, no rpc connection");
@@ -497,7 +500,7 @@ impl TrClient {
     /// `metainfo` is the base64 encoded content of a .torrent file
     pub async fn add_torrent_by_metainfo(&self, metainfo: String) -> Result<(), ClientError> {
         if let Some(client) = self.rpc_client() {
-            client.torrent_add_metainfo(&metainfo).await?;
+            client.torrent_add_metainfo(&metainfo).compat().await?;
             self.refresh_data().await;
         } else {
             warn!("Unable to add new torrent, no rpc connection");
@@ -527,6 +530,7 @@ impl TrClient {
         if let Some(client) = self.rpc_client() {
             client
                 .torrent_remove(Some(remove_hashes), delete_local_data)
+                .compat()
                 .await?;
             self.refresh_data().await;
         } else {
@@ -547,7 +551,10 @@ impl TrClient {
         }
 
         if let Some(client) = self.rpc_client() {
-            client.torrent_start(Some(start_hashes), false).await?;
+            client
+                .torrent_start(Some(start_hashes), false)
+                .compat()
+                .await?;
             self.refresh_data().await;
         } else {
             warn!("Unable to start torrents, no rpc connection")
@@ -566,7 +573,7 @@ impl TrClient {
         }
 
         if let Some(client) = self.rpc_client() {
-            client.torrent_stop(Some(stop_hashes)).await?;
+            client.torrent_stop(Some(stop_hashes)).compat().await?;
 
             // The daemon needs a short time to stop the torrents
             glib::timeout_future(Duration::from_millis(500)).await;
@@ -582,7 +589,7 @@ impl TrClient {
     /// timeout
     pub async fn refresh_data(&self) {
         if let Err(err) = self.imp().poll_data(false).await {
-            warn!("Couldn't poll transmission data: {}", err.to_string());
+            warn!("Couldn't poll transmission data: {err}");
             self.clone().disconnect(false).await;
             self.emit_by_name::<()>("connection-failure", &[]);
         }
